function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/* eslint-disable react/jsx-no-constructed-context-values */
import styled from 'styled-components';
import { IconContext } from 'phosphor-react';
import React, { useContext, useImperativeHandle, useRef, useState } from 'react';
import { Spinner } from '../spinner';
import { colorMap, sizeMap } from './buttonStyle';
import { LinkContext } from '../../context/linkContext';
import { ButtonToolTipBox } from './buttonTooltip';
const StyledButton = styled.button`
    display: flex;
    justify-content: center;
    align-items: center;
    user-select: none;
    position: relative;
    font-size: 14px;
    border: 0;
    text-decoration: none;
    transition: 150ms;
    font-weight: 500;
    line-height: 20px;
    gap: 8px;
    cursor: pointer;
    border-radius: ${props => props.$borderRadius}px;

    &::after {
        content: '';
        position: absolute;
        z-index: 1;
        top: 0px;
        right: 0px;
        bottom: 0px;
        left: 0px;
        transition: 200ms;
        display: block;
        pointer-events: none;
        border-radius: 4px;
        outline: solid 2px transparent;
    }

    &:focus-visible {
        outline: none;
        transition: 200ms;

        &::after {
            top: -3px;
            right: -3px;
            bottom: -3px;
            left: -3px;
        }
    }

    &:disabled {
        cursor: not-allowed;
    }

    ${props => sizeMap[props.$size]};
    ${props => colorMap[props.$variant][props.$color]};
`;
/**
 * 버튼
 */

export const Button = /*#__PURE__*/React.forwardRef(({
  as,
  children,
  variant = 'default',
  isLoading = false,
  color = 'gray',
  size = 'medium',
  icon,
  iconPosition = 'start',
  onClick,
  type = 'button',
  borderRadius = 4,
  width = 'fit-content',
  disabled = false,
  to,
  tooltip,
  ...props
}, ref) => {
  const inputRef = useRef(null);
  useImperativeHandle(ref, () => inputRef.current);
  const {
    Link
  } = useContext(LinkContext);
  const [isHover, setIsHover] = useState(false); // 아이콘

  let Icon;

  if (typeof icon === 'string') {
    Icon = /*#__PURE__*/React.createElement("img", {
      src: icon,
      alt: ""
    });
  }

  const buttonChildren = /*#__PURE__*/React.createElement(IconContext.Provider, {
    value: {
      size: 16,
      weight: 'bold'
    }
  }, isLoading && /*#__PURE__*/React.createElement(Spinner, {
    size: 16,
    color: "var(--local-color)"
  }), !isLoading && iconPosition === 'start' && (Icon || icon), !isLoading && children, !isLoading && iconPosition === 'end' && (Icon || icon));
  const iconOnly = !children && !!icon && width === 'fit-content';

  if (Link && to && !as) {
    const Element = Link || 'button';
    return /*#__PURE__*/React.createElement(StyledButton, _extends({}, props, {
      ref: inputRef,
      $width: width,
      onClick: () => onClick && onClick(),
      $color: color,
      $size: size,
      $variant: variant,
      type: type,
      $borderRadius: borderRadius,
      disabled: disabled,
      $iconOnly: iconOnly,
      as: Element,
      to: to,
      href: to,
      onMouseOver: e => {
        setIsHover(true);
        if (props.onMouseOver) props.onMouseOver(e);
      },
      onMouseOut: e => {
        setIsHover(false);
        if (props.onMouseOut) props.onMouseOut(e);
      }
    }), buttonChildren);
  }

  const Element = as || 'button';
  const PreButton = /*#__PURE__*/React.createElement(StyledButton, _extends({}, props, {
    ref: inputRef,
    $width: width,
    onClick: e => onClick && onClick(e),
    $color: color,
    $size: size,
    $variant: variant,
    type: type,
    $borderRadius: borderRadius,
    disabled: disabled,
    $iconOnly: iconOnly,
    as: Element,
    onMouseOver: e => {
      setIsHover(true);
      if (props.onMouseOver) props.onMouseOver(e);
    },
    onMouseOut: e => {
      setIsHover(false);
      if (props.onMouseOut) props.onMouseOut(e);
    }
  }), buttonChildren);

  if (tooltip) {
    const pos = {
      top: -1,
      right: -1,
      bottom: -1,
      left: -1
    }; // x: inputRef.current?.getBoundingClientRect().left,
    // y: inputRef.current?.getBoundingClientRect().top,

    switch (tooltip.direction || 'top') {
      case 'right':
        pos.left = inputRef.current?.offsetLeft + inputRef.current?.offsetWidth;
        pos.top = inputRef.current?.offsetTop + inputRef.current?.offsetHeight / 2;
        break;

      case 'bottom':
        pos.left = inputRef.current?.offsetLeft + inputRef.current?.offsetWidth / 2;
        pos.top = inputRef.current?.offsetTop + inputRef.current?.offsetHeight;
        break;

      case 'left':
        pos.right = document.documentElement.scrollWidth - inputRef.current?.offsetLeft - inputRef.current?.offsetWidth;
        pos.top = inputRef.current?.offsetTop + inputRef.current?.offsetHeight / 2;
        break;

      case 'top':
      default:
        pos.left = inputRef.current?.offsetLeft + inputRef.current?.offsetWidth / 2;
        pos.bottom = document.body.offsetHeight - inputRef.current?.offsetTop - inputRef.current?.offsetHeight;
        break;
    }

    const f = e => e === -1 ? 'auto' : `${e}px`;

    const inset = `${f(pos.top)} ${f(pos.right)} ${f(pos.bottom)} ${f(pos.left)}`;
    return /*#__PURE__*/React.createElement(React.Fragment, null, PreButton, isHover && /*#__PURE__*/React.createElement(ButtonToolTipBox, {
      text: tooltip.text,
      direction: tooltip.direction || 'top',
      pos: inset
    }));
  }

  return PreButton;
});